==> lumina-1.1.0.tar.gz: lumina-1.1.0/src-qt5/desktop-utils/lumina-screenshot/i18n/l-screenshot_he.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="he">
<context>
    <name>ImageEditor</name>
    <message>
        <location filename="../ImageEditor.cpp" line="14"/>
        <source>Zoom In</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ImageEditor.cpp" line="15"/>
        <source>Zoom Out</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainUI</name>
    <message>
        <location filename="../MainUI.ui" line="14"/>
        <location filename="../MainUI.ui" line="162"/>
        <location filename="../MainUI.ui" line="295"/>
        <source>Take Screenshot</source>
        <translation>תפוס צילום מסך</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="37"/>
        <source>New Screenshot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="43"/>
        <source>Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="124"/>
        <source>Include Borders</source>
        <translation>כלול מסגרת</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="149"/>
        <source> Seconds</source>
        <translation> שניות</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="152"/>
        <source>Delay </source>
        <translation>שיהוי </translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="172"/>
        <source>View/Edit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="212"/>
        <location filename="../MainUI.ui" line="306"/>
        <source>Save As</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="222"/>
        <source>Launch Editor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="245"/>
        <source>Crop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="255"/>
        <source>Resize</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="282"/>
        <source>File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="298"/>
        <source>Ctrl+N</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="322"/>
        <source>Close</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="325"/>
        <source>Esc</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="67"/>
        <source>Entire Session</source>
        <translation>סשן שלם</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="81"/>
        <source>Single Window</source>
        <translation>חלון בודד</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="74"/>
        <source>Single Screen</source>
        <translation>מסך בודד</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="77"/>
        <source>Save Screenshot</source>
        <translation>שמור צילום מסך</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="309"/>
        <source>Ctrl+S</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="317"/>
        <source>Quick Save</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="77"/>
        <source>PNG Files (*.png);;AllFiles (*)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> lumina-1.2.0.tar.gz: lumina-1.2.0/src-qt5/desktop-utils/lumina-screenshot/i18n/l-screenshot_he.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="he">
<context>
    <name>ImageEditor</name>
    <message>
        <location filename="../ImageEditor.cpp" line="14"/>
        <source>Zoom In</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ImageEditor.cpp" line="15"/>
        <source>Zoom Out</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainUI</name>
    <message>
        <location filename="../MainUI.ui" line="375"/>
        <source>Take Screenshot</source>
        <translation>תפוס צילום מסך</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="151"/>
        <source>Include Borders</source>
        <translation>כלול מסגרת</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="196"/>
        <location filename="../MainUI.ui" line="386"/>
        <source>Save As</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="244"/>
        <source>Crop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="228"/>
        <source>Resize</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="20"/>
        <source>Lumina Screenshot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="70"/>
        <source> Sec Delay</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="183"/>
        <source>Capture</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="212"/>
        <source>Edit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="362"/>
        <source>File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="378"/>
        <source>Ctrl+N</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="402"/>
        <source>Close</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="405"/>
        <source>Esc</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="57"/>
        <source>Entire Session</source>
        <translation>סשן שלם</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="138"/>
        <source>Single Window</source>
        <translation>חלון בודד</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="99"/>
        <source>Single Screen</source>
        <translation>מסך בודד</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="79"/>
        <source>Could not save screenshot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="79"/>
        <source>The screenshot could not be saved. Please check directory permissions or pick a different directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="86"/>
        <source>Save Screenshot</source>
        <translation>שמור צילום מסך</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="389"/>
        <source>Ctrl+S</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="397"/>
        <source>Quick Save</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="86"/>
        <source>PNG Files (*.png);;AllFiles (*)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
